==> estateplat-common-1.2.3-20180427.083444-69-sources.jar: cn/gtmap/estateplat/service/commodity/house/FcjyXjsfpRemoteService.java <==
package cn.gtmap.estateplat.service.commodity.house;

import cn.gtmap.estateplat.model.commodityHouse.projectManage.FcjyXjspfKfxm;
import cn.gtmap.estateplat.model.commodityHouse.projectManage.FcjyXjspfLjz;

import java.util.List;

/**
 * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
 * @version 1.0, 2018-3-21
 * @description 房产交易新建商品房接口服务
 */
public interface FcjyXjsfpRemoteService {
    /**
     * @param fdckfqybh 房地产开发企业编号
     * @return 新建商品房开发项目
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description 根据房地产开发企业编号获取新建商品房开发项目
     */
    List<FcjyXjspfKfxm> getFcjyXjspfKfxmByFdckfqybh(String fdckfqybh);

    /**
     * @param xmid 项目ID
     * @return 新建商品逻辑幢
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description 根据项目ID获取新建商品逻辑幢
     */
    List<FcjyXjspfLjz> getFcjyXjspfLjzByXmid(String xmid);

    /**
     * @param fdckfqybh 房地产开发企业编号
     * @return 新建商品逻辑幢
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description 根据房地产开发企业编号获取新建商品逻辑幢
     */
    List<FcjyXjspfLjz> getFcjyXjspfLjzByFdckfqybh(String fdckfqybh);

    /**
     * @param fdckfqybh 房地产开发企业编号
     * @param ljzh      逻辑幢号
     * @param lszd      隶属宗地
     * @param zldz      坐落
     * @return 新建商品逻辑幢
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description 根据房地产开发企业编号、逻辑幢号、隶属宗地、坐落获取新建商品逻辑幢
     */
    List<FcjyXjspfLjz> getFcjyXjspfLjzByFdckfqybhMore(String fdckfqybh, String ljzh, String lszd, String zldz);

    /**
     * @param xmid 项目ID
     * @param ljzh 逻辑幢号
     * @param lszd 隶属宗地
     * @param zldz 坐落
     * @return 新建商品逻辑幢
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description 根据项目ID、逻辑幢号、隶属宗地、坐落获取新建商品逻辑幢
     */
    List<FcjyXjspfLjz> getFcjyXjspfLjzByXmidMore(String xmid, String ljzh, String lszd, String zldz);
}

==> estateplat-common-1.2.3-20180514.060258-83-sources.jar: cn/gtmap/estateplat/service/commodity/house/FcjyXjsfpRemoteService.java <==
package cn.gtmap.estateplat.service.commodity.house;

import cn.gtmap.estateplat.model.commodityHouse.projectManage.FcjyXjspfKfxm;
import cn.gtmap.estateplat.model.commodityHouse.projectManage.FcjyXjspfLjz;

import java.util.List;

/**
 * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
 * @version 1.0, 2018-3-21
 * @description 房产交易新建商品房接口服务
 */
public interface FcjyXjsfpRemoteService {
    /**
     * @param fdckfqybh 房地产开发企业编号
     * @return 新建商品房开发项目
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description 根据房地产开发企业编号获取新建商品房开发项目
     */
    List<FcjyXjspfKfxm> getFcjyXjspfKfxmByFdckfqybh(String fdckfqybh);

    /**
     * @param xmid 项目ID
     * @return 新建商品逻辑幢
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description 根据项目ID获取新建商品逻辑幢
     */
    List<FcjyXjspfLjz> getFcjyXjspfLjzByXmid(String xmid);

    /**
     * @param fdckfqybh 房地产开发企业编号
     * @return 新建商品逻辑幢
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description 根据房地产开发企业编号获取新建商品逻辑幢
     */
    List<FcjyXjspfLjz> getFcjyXjspfLjzByFdckfqybh(String fdckfqybh);

    /**
     * @param fdckfqybh 房地产开发企业编号
     * @param ljzh      逻辑幢号
     * @param lszd      隶属宗地
     * @param zldz      坐落
     * @return 新建商品逻辑幢
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description 根据房地产开发企业编号、逻辑幢号、隶属宗地、坐落获取新建商品逻辑幢
     */
    List<FcjyXjspfLjz> getFcjyXjspfLjzByFdckfqybhMore(String fdckfqybh, String ljzh, String lszd, String zldz);

    /**
     * @param xmid 项目ID
     * @param ljzh 逻辑幢号
     * @param lszd 隶属宗地
     * @param zldz 坐落
     * @return 新建商品逻辑幢
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description 根据项目ID、逻辑幢号、隶属宗地、坐落获取新建商品逻辑幢
     */
    List<FcjyXjspfLjz> getFcjyXjspfLjzByXmidMore(String xmid, String ljzh, String lszd, String zldz);

    /** * @author <a href="mailto:lizhi@gtmap.cn">lizhi</a>
     * @param
     * @rerutn    1是有预销售许可，0是没有预销售许可
     * @description   根据ljzid判断是否有预售许可
     */
    Integer checkYxsxkByLjzid(List<String> ljzidList);
}
